@@ -11,7 +11,7 @@ use Math::BigInt;
 use Math::BigFloat;
 use Data::Dumper;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 
 =pod
@@ -255,7 +255,7 @@ our $VERSION = '0.26';
 
   Net::Ethereum - Perl Framework for Ethereum JSON RPC API.
 
-  It is alpha debugging version.
+  This is alpha debugging version.
 
   Currently support marshaling only uint, int, bool, string types.
 
@@ -1342,9 +1342,10 @@ sub compile_and_deploy_contract()
 sub _read_file()
 {
   my ($this, $file_path) = @_;
-  open FILE, "<", $file_path or die "Can't open file: $!\n";
-  $/ = undef;
-  my $content = <FILE>;
+  open my $FILE, "<", $file_path or die "Can't open file: $!\n";
+  local $/ = undef;
+  my $content = <$FILE>;
+  close $FILE;
   return $content;
 }
 
